Algorithm implementations for rust-igraph.
Phase 0 walking-skeleton scope: only traversal::bfs and
io::read_edgelist. The full algorithm catalog is filled in by AWUs
across Phases 1-10 (see docs/plans/MASTER_PLAN.md).
Algorithm implementations for rust-igraph.
Phase 0 walking-skeleton scope: only traversal::bfs and
io::read_edgelist. The full algorithm catalog is filled in by AWUs
across Phases 1-10 (see docs/plans/MASTER_PLAN.md).