Connectivity algorithms. Phase 1: ALGO-CC-001 (weak connected components),
ALGO-CC-002 (strongly connected components), ALGO-CC-010 (articulation
points), ALGO-CC-013 (is_biconnected), ALGO-CC-014 (bridges),
ALGO-CC-020 (reachability counts), ALGO-CC-021 (reachability matrix),
ALGO-CC-022 (transitive closure).
Structs
- Biconnected
Components - Output of
biconnected_components. - Connected
Components - Result of a weak connected-components scan.
- Edgelist
Percolation - Outputs of
edgelist_percolation. Same length as the input edge slice.giant_size[i]is the size of the largest component after edgeiis added;vertex_count[i]is the number of distinct vertices touched by edges0..=i. - Site
Percolation - Outputs of
site_percolation. Same length asvertex_order.giant_size[i]is the size of the largest connected component after vertexvertex_order[i]is activated;edge_count[i]is the cumulative number of edges added through stepi(an edge is “added” the moment both its endpoints become active).
Functions
- articulation_
points - Articulation points of
graph(returns vertices in upstream’s DFS-discovery order). - biconnected_
components - Compute the biconnected components of
graph. - bond_
percolation - Bond percolation: the size of the largest component as edges of
graphare added in the order specified byedge_order. - bridges
- Bridges of
graph— edges whose removal would increase the number of (weakly) connected components. - connected_
components - Compute the weak connected components of
graph. - count_
reachable - Per-vertex count of reachable vertices (including the vertex itself).
- decompose
- Decompose
graphinto its weakly connected components. - edgelist_
percolation - Percolation curve as a sequence of vertex-pair edges is added.
- is_
biconnected - Check whether
graphis biconnected. - reachability_
matrix - Dense reachability matrix of
graph.result[i][j]istrueiff vertexjis reachable fromiin zero or more steps. - site_
percolation - Site percolation: the size of the largest component as vertices
(sites) of
graphare activated in the order specified byvertex_order. - strongly_
connected_ components - Compute the strongly connected components of
graph. - transitive_
closure - Transitive closure of
graph. The returned graph shares the same vertex count and direction as the input.